@@ -2,44 +2,40 @@ package SPVM::BlessedObject::Array;
 
 use base 'SPVM::BlessedObject';
 
-use overload '@{}' => sub {
-  my ($array) = @_;
-  
-  my $elements = $array->to_elems;
-  
-  return $elements;
-};
-
 use SPVM::ExchangeAPI;
 
-sub length {
-  my $self = shift;
-  
-  SPVM::ExchangeAPI::array_length($SPVM::BUILDER, $self);
-}
+use overload bool => sub {1}, '""' => sub { shift->to_str }, fallback => 1;
 
 sub to_elems {
   my $self = shift;
   
-  SPVM::ExchangeAPI::array_to_elems($SPVM::BUILDER, $self);
+  my $env = $self->{env};
+  
+  SPVM::ExchangeAPI::to_elems($env, $self);
 }
 
 sub to_bin {
   my $self = shift;
 
-  SPVM::ExchangeAPI::array_to_bin($SPVM::BUILDER, $self);
+  my $env = $self->{env};
+  
+  SPVM::ExchangeAPI::to_bin($env, $self);
 }
 
-sub set {
+sub to_str {
   my $self = shift;
   
-  SPVM::ExchangeAPI::array_set($SPVM::BUILDER, $self, @_);
+  my $env = $self->{env};
+  
+  SPVM::ExchangeAPI::to_str($env, $self);
 }
 
-sub get {
+sub to_strs {
   my $self = shift;
   
-  SPVM::ExchangeAPI::array_get($SPVM::BUILDER, $self, @_);
+  my $env = $self->{env};
+  
+  SPVM::ExchangeAPI::to_strs($env, $self);
 }
 
 1;
@@ -55,12 +51,6 @@ SPVM::BlessedObject::Array is array based blessed object.
 This object contains SPVM array object.
 
 =head1 SYNOPSYS
-
-  # Get the value of a array element
-  my $value = $spvm_nums->get(2);
-
-  # Set the value of a array element
-  $spvm_nums->set(2 => 5);
   
   # Convert SPVM array to Perl array reference
   my $nums = $spvm_nums->to_elems;
@@ -68,20 +58,14 @@ This object contains SPVM array object.
   # Convert SPVM array to Perl binary data
   my $binary = $spvm_nums->to_bin;
   
+  # Convert SPVM array to perl text str(decoded str).
+  my $str = $spvm_str->to_str;
+
+  # Convert SPVM array to perl array reference which contains decoded strings.
+  my $strs = $spvm_strs->to_strs;
+
 =head1 METHODS
 
-=head2 get
-
-  my $value = $spvm_nums->get(2);
-
-Get the value of a array element.
-
-=head2 set
-
-  $spvm_nums->set(2 => 5);
-
-Set the value of a array element
-
 =head2 to_elems
 
   my $nums = $spvm_nums->to_elems;
@@ -100,17 +84,14 @@ An exmaple when array is int array:
 
   my @nums = unpack 'l*', $binary;
 
-=head1 OPERATORS
+=head2 to_str
 
-L<SPVM::BlessedObject::Array> overloads the following operators.
+  my $str = $spvm_str->to_str;
 
-=head2 array dereference
-  
-Array dereference get the elements of the array.
+Convert SPVM array to perl text str(decoded str).
 
-  # Get elements
-  my @elements = @$array;
+=head2 to_strs
 
-This is the same as the following.
+  my $strs = $spvm_strs->to_strs;
 
-  my @elements = @{$array->to_elems};
+Convert SPVM array to perl array reference which contains decoded strings.
