@@ -221,10 +221,10 @@ sub create_package_make_rule {
   my $spvm_file = $noext_file;
   $spvm_file .= '.spvm';
   $spvm_file = "$src_dir/$spvm_file";
-
-  my $c_file = $noext_file;
-  $c_file .= '.c';
-  $c_file = "$src_dir/$c_file";
+  
+  my $native_c_file = $noext_file;
+  $native_c_file .= '.c';
+  $native_c_file = "$src_dir/$native_c_file";
 
   my $config_file = $noext_file;
   $config_file .= '.config';
@@ -237,7 +237,12 @@ sub create_package_make_rule {
   push @deps, grep { $_ ne '.' && $_ ne '..' } glob "$src_dir/$package_rel_file/*";
   
   # Dependency module file
-  push @deps, $spvm_file, $c_file, $config_file;
+  if ($category eq 'native') {
+    push @deps, $spvm_file, $native_c_file, $config_file;
+  }
+  elsif ($category eq 'precompile') {
+    push @deps, $spvm_file;
+  }
   
   # Shared library file
   my $dll_rel_file = convert_package_name_to_dll_category_rel_file($package_name, $category);
