@@ -467,6 +467,14 @@ const char* const SPVM_OPCODE_C_ID_NAMES[] = {
   "UNWEAKEN_FIELD",
   "ISWEAK_FIELD",
   "REFCNT",
+  "COMPLEX_ADD_FLOAT",
+  "COMPLEX_ADD_DOUBLE",
+  "COMPLEX_SUBTRACT_FLOAT",
+  "COMPLEX_SUBTRACT_DOUBLE",
+  "COMPLEX_MULTIPLY_FLOAT",
+  "COMPLEX_MULTIPLY_DOUBLE",
+  "COMPLEX_DIVIDE_FLOAT",
+  "COMPLEX_DIVIDE_DOUBLE",
   "END_SUB",
 };
 
